@@ -1,14 +1,21 @@
 import json
 from datetime import datetime
-from typing import Optional, Dict, List, TYPE_CHECKING
+from typing import Optional, Dict, TYPE_CHECKING
 
 if TYPE_CHECKING:
     from . import Client
+    from .PaginatedList import PaginatedList
 
-from .const import TRANSACTION_SETTLED
+from .const import TRANSACTION_SETTLED, DEFAULT_LIMIT, DEFAULT_PAGE_SIZE
 
 
-class Transaction:
+class ModelBase:
+    def __init__(self, client: "Client", data: Dict):
+        self._client = client
+        self.raw = data
+
+
+class Transaction(ModelBase):
     """Representation of a transaction
 
     id: the unique id of the transaction
@@ -24,8 +31,8 @@ class Transaction:
     raw: the raw serialised data from the api
     """
 
-    def __init__(self, data):
-        self.raw: Dict = data
+    def __init__(self, client: "Client", data):
+        super().__init__(client, data)
         self.id: str = data["id"]
 
         attributes = data["attributes"]
@@ -53,7 +60,7 @@ class Transaction:
         return f"<Transaction {self.status}: {self.amount} {self.currency} [{self.description}]>"
 
 
-class Account:
+class Account(ModelBase):
     """Representation of a transaction
 
     id: the unique id of the account
@@ -66,8 +73,7 @@ class Account:
     """
 
     def __init__(self, client: "Client", data: Dict):
-        self._client = client
-        self.raw: Dict = data
+        super().__init__(client, data)
         self.id: str = data["id"]
 
         attributes = data["attributes"]
@@ -80,14 +86,33 @@ class Account:
 
     def transactions(
         self,
-        limit: int = 20,
+        limit: Optional[int] = DEFAULT_LIMIT,
+        page_size: int = DEFAULT_PAGE_SIZE,
+        status: str = None,
         since: datetime = None,
         until: datetime = None,
+        category: str = None,
         tag: str = None,
-    ) -> List[Transaction]:
-        """Returns the transactions for this account."""
+    ) -> "PaginatedList[Transaction]":
+        """Returns the transactions for this account.
+
+        :param limit maximum number of records to return (set to None for all transactions)
+        :param page_size number of records to fetch in each request (max 100)
+        :param status:
+        :param since:
+        :param until:
+        :param category:
+        :param tag:
+        """
         return self._client.transactions(
-            limit=limit, since=since, until=until, tag=tag, account_id=self.id
+            limit=limit,
+            page_size=page_size,
+            status=status,
+            since=since,
+            until=until,
+            category=category,
+            tag=tag,
+            account_id=self.id,
         )
 
     def __repr__(self) -> str:
@@ -95,7 +120,7 @@ class Account:
         return f"<Account '{self.name}' ({self.type}): {self.balance} {self.currency}>"
 
 
-class Webhook:
+class Webhook(ModelBase):
     """Representation of a webhook
 
     id: the unique id of the webhook
@@ -107,8 +132,7 @@ class Webhook:
     """
 
     def __init__(self, client: "Client", data: Dict):
-        self._client = client
-        self.raw: Dict = data
+        super().__init__(client, data)
         self.id: str = data["id"]
 
         attributes = data["attributes"]
@@ -122,9 +146,15 @@ class Webhook:
         """Sends a ping event to the webhook"""
         return self._client.webhook.ping(self.id)
 
-    def logs(self, limit: int = 20) -> List["WebhookLog"]:
-        """Returns the transactions for this account."""
-        return self._client.webhook.logs(self.id, limit=limit)
+    def logs(
+        self, limit: Optional[int] = DEFAULT_LIMIT, page_size: int = DEFAULT_PAGE_SIZE
+    ) -> PaginatedList["WebhookLog"]:
+        """Returns the logs of this webhook.
+
+        :param limit maximum number of records to return (set to None for all transactions)
+        :param page_size number of records to fetch in each request (max 100)
+        """
+        return self._client.webhook.logs(self.id, limit=limit, page_size=page_size)
 
     def delete(self):
         """Deletes the webhook."""
@@ -137,7 +167,7 @@ class Webhook:
         return f"<Webhook '{self.id}': {self.url}>"
 
 
-class WebhookLog:
+class WebhookLog(ModelBase):
     """Representation of a webhook log entry
 
     id: the unique id of the log entry
@@ -150,8 +180,7 @@ class WebhookLog:
     """
 
     def __init__(self, client: "Client", data: Dict):
-        self._client = client
-        self.raw: Dict = data
+        super().__init__(client, data)
         self.id: str = data["id"]
 
         attributes = data["attributes"]
@@ -174,7 +203,7 @@ class WebhookLog:
         return f"<WebhookLog {self.delivery_status}>"
 
 
-class WebhookEvent:
+class WebhookEvent(ModelBase):
     """Representation of a webhook event
 
     id: the unique id of the event
@@ -186,8 +215,7 @@ class WebhookEvent:
     """
 
     def __init__(self, client: "Client", data: Dict):
-        self._client = client
-        self.raw: Dict = data
+        super().__init__(client, data)
         self.id: str = data["id"]
 
         attributes = data["attributes"]
